/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://java.net/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.taxonomy;

import javax.annotation.Nonnull;
import org.openide.util.Lookup;
import it.tidalwave.util.As;
import it.tidalwave.util.NotFoundException;

/***********************************************************************************************************************
 *
 * A manager for creating and retrieving {@link Taxonomy} instances.
 * 
 * 
 * @stereotype Role
 * @navassoc - "<create>" - Taxonomy.Builder
 * @composed "1" "<finds>" "0..*" Taxonomy
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public interface TaxonomyManager extends Lookup.Provider, As
  {
    public static final Class<TaxonomyManager> TaxonomyManager = TaxonomyManager.class;
    
    /*******************************************************************************************************************
     *
     * Creates a {@link Taxonomy}.
     *
     * @return              the {@code Taxonomy}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Taxonomy.Builder createTaxonomy();

    /*******************************************************************************************************************
     *
     * Finds a {@link Taxonomy} in an existing repository.
     *
     * @param  displayName  the name of the {@code Taxonomy} to retrieve
     * @param  repository   the repository
     * @return              the {@code Taxonomy}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Taxonomy findTaxonomyByName (@Nonnull String displayName,
                                        @Nonnull Object repository)
      throws NotFoundException;
  }
